@@ -12,15 +12,18 @@ DEFAULT_PATHS = ['/usr/bin',
                  '/opt/local/bin',
                  '/usr/pkg/libexec/cgi-bin']
 
+# IANA: TCP ports 47809-47999 are unassigned
+
 class Wizard_Rules_PHP (Wizard):
-    UNIX_SOCK     = "/tmp/cherokee-php.socket"
+    TCP_PORT      = 47990
     ICON          = "php.jpg"
-    DESC          = "Configures PHP in the current Virtual Server. It will add a new .php extension is not present."
-    
+    DESC          = "Configures PHP in the current Virtual Server. It will add a new .php extension if not present."
+
     def __init__ (self, cfg, pre):
         Wizard.__init__ (self, cfg, pre)
         self.name   = "Add PHP support"
         self.source = None
+        self.group  = WIZARD_GROUP_LANGS    
 
     def show (self):
         self.rule   = None
@@ -62,8 +65,8 @@ class Wizard_Rules_PHP (Wizard):
             _, self.source = cfg_source_get_next (self._cfg)
             self._cfg['%s!nick' % (self.source)]        = 'PHP Interpreter'
             self._cfg['%s!type' % (self.source)]        = 'interpreter'
-            self._cfg['%s!interpreter' % (self.source)] = '%s -b %s' % (php_path, self.UNIX_SOCK)
-            self._cfg['%s!host' % (self.source)]        = self.UNIX_SOCK
+            self._cfg['%s!interpreter' % (self.source)] = '%s -b localhost:%d' % (php_path, self.TCP_PORT)
+            self._cfg['%s!host' % (self.source)]        = 'localhost:%d' % (self.TCP_PORT)
 
             self._cfg['%s!env!PHP_FCGI_MAX_REQUESTS' % (self.source)] = "5000"
             self._cfg['%s!env!PHP_FCGI_CHILDREN' % (self.source)]     = "5"
