@@ -106,7 +106,7 @@ cherokee_admin_client_prepare (cherokee_admin_client_t *admin,
 	if ((admin->url_ref == NULL) || 
 	    (admin->poll_ref == NULL))
 	{
-		PRINT_ERROR_S ("ERROR: Internal error\n");
+		LOG_CRITICAL_S ("Internal error\n");
 		return ret_error;
 	}
 	
@@ -213,14 +213,14 @@ prepare_and_set_post (cherokee_admin_client_t *admin, const char *str, cuint_t s
 	prepare_and_set_post(admin, str"\n", sizeof(str))
 
 
-#define CHECK_AND_SKIP_LITERAL(string, substr) \
-	if ((string == NULL) || (strlen(string) == 0)) \
-		return ret_error; \
-	if (strncmp (string, substr, sizeof(substr)-1)) { \
-		PRINT_ERROR ("ERROR: Uknown response len(" FMT_SIZE "): '%s'\n", \
-			     (CST_SIZE) strlen(string), string); \
-		return ret_error; \
-	} \
+#define CHECK_AND_SKIP_LITERAL(string, substr)				\
+	if ((string == NULL) || (strlen(string) == 0))			\
+		return ret_error;					\
+	if (strncmp (string, substr, sizeof(substr)-1)) {		\
+		LOG_ERROR ("Uknown response len(" FMT_SIZE "): '%s'\n", \
+			   (CST_SIZE) strlen(string), string);		\
+		return ret_error;					\
+	}								\
 	string += sizeof(substr)-1;
 
 
@@ -236,8 +236,8 @@ check_and_skip_literal (cherokee_buffer_t *buf, const char *literal)
 	re = strncmp (buf->buf, literal, len);
 	if (re != 0) {
 #if 0
-		PRINT_ERROR ("ERROR: Couldn't find len(%d):'%s' in len(%d):'%s'\n", 
-			     strlen(literal), literal, buf->len, buf->buf);
+		LOG_ERROR ("Couldn't find len(%d):'%s' in len(%d):'%s'\n", 
+			   strlen(literal), literal, buf->len, buf->buf);
 #endif
 		return ret_error;
 	}
