@@ -411,9 +411,11 @@ _init_template (cherokee_logger_custom_t *logger,
 
 
 static void 
-bogotime_callback (void) 
+bogotime_callback (void *param) 
 {
 	struct tm *pnow_tm = &cherokee_bogonow_tmloc;
+
+	UNUSED (param);
 	
 	cherokee_buffer_clean  (&now);
 	cherokee_buffer_add_va (&now,
@@ -489,7 +491,7 @@ cherokee_logger_custom_new (cherokee_logger_t         **logger,
 	 */
 	if (callback_init == 0) {
 		cherokee_buffer_init (&now);
-		cherokee_bogotime_add_callback (bogotime_callback);
+		cherokee_bogotime_add_callback (bogotime_callback, NULL, 1);
 	}
 
 	/* Return the object
