@@ -56,6 +56,7 @@
 #include "version.h"
 #include "cryptor.h"
 #include "logger_writer.h"
+#include "collector.h"
 
 struct cherokee_server {
 	/* Exit related
@@ -91,6 +92,8 @@ struct cherokee_server {
 
 	/* Programmed tasks
 	 */
+	cherokee_collector_t      *collector;
+
 	cherokee_list_t            logger_writers;
 	cherokee_avl_t             logger_writers_index;
 
@@ -175,7 +178,7 @@ struct cherokee_server {
 
 
 ret_t cherokee_server_del_connection (cherokee_server_t *srv, char *begin);
-ret_t cherokee_server_get_vserver    (cherokee_server_t *srv, cherokee_buffer_t *name, cherokee_virtual_server_t **vsrv);
+ret_t cherokee_server_get_vserver    (cherokee_server_t *srv, cherokee_buffer_t *name, cherokee_connection_t *conn, cherokee_virtual_server_t **vsrv);
 ret_t cherokee_server_get_next_bind  (cherokee_server_t *srv, cherokee_bind_t *bind, cherokee_bind_t **next);
 ret_t cherokee_server_get_log_writer (cherokee_server_t *srv, cherokee_config_node_t *config, cherokee_logger_writer_t **writer);
 
