@@ -15,7 +15,8 @@ vserver!1250!rule!10!handler!rewrite!1!substring = http://www.<domain>/$1
 
 vserver!1251!nick = www.<domain>
 vserver!1251!document_root = %s
-vserver!1251!domain!1 = www.<domain>
+vserver!1251!match = wildcard
+vserver!1251!match!domain!1 = www.<domain>
 """
 
 class Test (TestBase):
